/**
 * @file icmp-light_types.h
 *
 * @brief Internet Control Message Protocol (ICMP) - minimal implemenation (types).
 *
 * Copyright 2007-2008, Freie Universitaet Berlin. All rights reserved.
 * Please refer to the COPYING file for detailed licensing information.
 *
 * @author Georg Wittenburg
 *
 * $Id: icmp-light_types.h 2548 2008-02-13 19:20:58Z wittenbu $
 */

#ifndef ICMP_LIGHT_TYPES_H
#define ICMP_LIGHT_TYPES_H

#include "../types.h"



/**
 * @brief Results of an echo request.
 */
typedef struct {
	SP_list_t*			nodes;			///< List of nodes that replied.
	SP_errno_t			errno;			///< Error code.
	SP_callback_parameter_t		parameter;		///< Parameter set by the calling function.
} SP_ICMP_echo_request_result_t;

/**
 * @brief Echo request data structure.
 */
typedef struct {
	bool				active;			///< Status of the request.
	u_int8_t			max_nodes;		///< Maximal number of replies.
	SP_callback_function_t		function;		///< Callback function.
	SP_ICMP_echo_request_result_t*	echo_request_result;	///< Pointer to results.
	bool				too_many_replies;	///< Flag for excessive replies.
} SP_ICMP_echo_request_t;

#endif	// ICMP_LIGHT_TYPES_H
