/**
 * @file placement_types.h
 *
 * @brief Placement (types).
 *
 * Copyright 2007-2008, Freie Universitaet Berlin. All rights reserved.
 * Please refer to the COPYING file for detailed licensing information.
 *
 * @author Georg Wittenburg
 *
 * $Id: placement_types.h 2548 2008-02-13 19:20:58Z wittenbu $
 */

#ifndef PLACEMENT_TYPES_H
#define PLACEMENT_TYPES_H

#include "../types.h"

/**
 * @brief Node statistics.
 */
typedef struct {
	SP_node_t	node;				///< Node to which these statistics belong.
	u_int32_t	service_requests_count;		///< Number of service requests from this node.
	u_int32_t	service_requests_traffic;	///< Traffic of service requests from this node in bytes.
	u_int32_t	last_hop_count;			///< Number of service requests this node was the last routing hop for.
	u_int32_t	last_hop_traffic;		///< Traffic of service requests this node was the last routing hop for in bytes.
	bool		refused_migration;		///< Flag whether this node has refused a migration in the past.
} SP_PLACEMENT_node_stats_t;

/**
 * @brief Service statistics.
 */
typedef struct {
	u_int32_t	service_request_count;		///< Number of service requests (data, update or stream).
	u_int32_t	service_request_traffic;	///< Traffic caused by these service requests in bytes.
	SP_list_t*	node_stats;			///< List of node statistics for a service.
} SP_PLACEMENT_service_stats_t;



/*
 * Packet types.
 */



#endif	// PLACEMENT_TYPES_H
