/**
 * @file slp-light_types.h
 *
 * @brief Service Location Protocol (SLP) - minimal implemenation (types).
 *
 * Copyright 2007-2008, Freie Universitaet Berlin. All rights reserved.
 * Please refer to the COPYING file for detailed licensing information.
 *
 * @author Georg Wittenburg
 *
 * $Id: slp-light_types.h 2548 2008-02-13 19:20:58Z wittenbu $
 */

#ifndef SLP_LIGHT_TYPES_H
#define SLP_LIGHT_TYPES_H

#include "../types.h"
#include "../service/service_types.h"



/*
 * SLP query types.
 */

/**
 * @brief A service instance found by a SLP query.
 */
typedef struct {
	SP_addr_t		server;					///< Server address.
	u_int8_t		hops;					///< Distance to the server in hops.
	SP_time_t		delay;					///< Time it took the reply to arrive.
} SP_SLP_service_instance_t;

/**
 * @brief Result of a SLP query.
 */
typedef struct {
	char			service_id[SP_SERVICE_ID_LENGTH];	///< Service ID.
	SP_list_t*		service_instances;			///< List of found service instances.
	SP_errno_t		errno;					///< Error code.
	SP_callback_parameter_t	parameter;				///< Parameter for the callback function.
} SP_SLP_query_result_t;

/**
 * @brief Active query data structure.
 */
typedef struct {
	char			service_id[SP_SERVICE_ID_LENGTH];	///< Service ID.
	u_int8_t		min_service_instances;			///< Minimal number of found service instances before the query is done.
	u_int8_t		retries;				///< Number of retries left.
	SP_time_t		start_time;				///< Time since the current retry started.
	SP_callback_function_t	function;				///< Callback function.
	SP_SLP_query_result_t*	result;					///< Parameter for callback function.
} SP_SLP_query_t;



/*
 * Packet types.
 */

/**
 * @brief SLP QUERY packet.
 */
typedef struct {
	char			service_id[SP_SERVICE_ID_LENGTH];	///< Service ID.
} SP_SLP_QUERY_packet_t;

/**
 * @brief SLP REPLY packet.
 */
typedef struct {
	char			service_id[SP_SERVICE_ID_LENGTH];	///< Service ID.
} SP_SLP_REPLY_packet_t;

#endif	// SLP_LIGHT_TYPES_H
